summaryrefslogtreecommitdiff
path: root/usr.bin/make/compat.c
diff options
context:
space:
mode:
authorrillig <rillig@NetBSD.org>2020-11-08 08:33:07 +0000
committerrillig <rillig@NetBSD.org>2020-11-08 08:33:07 +0000
commit400a44e5bf3ddb6a0f241d73c362eff5ededd179 (patch)
treeea1019d93fad1f7f35197da1920abf84c969e186 /usr.bin/make/compat.c
parentb15c9760237a9c924081f4fe15d95bbcdd88afe5 (diff)
make(1): rename Make_OODate to GNode_IsOODate
It doesn't matter which of the make modules is in charge of determining whether a node is out-of-date. Therefore, remove the module name from the function name.
Diffstat (limited to 'usr.bin/make/compat.c')
-rw-r--r--usr.bin/make/compat.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/usr.bin/make/compat.c b/usr.bin/make/compat.c
index f89b087d521..ed1b3ea31d9 100644
--- a/usr.bin/make/compat.c
+++ b/usr.bin/make/compat.c
@@ -1,4 +1,4 @@
-/* $NetBSD: compat.c,v 1.180 2020/11/08 08:26:22 rillig Exp $ */
+/* $NetBSD: compat.c,v 1.181 2020/11/08 08:33:07 rillig Exp $ */
/*
* Copyright (c) 1988, 1989, 1990 The Regents of the University of California.
@@ -96,7 +96,7 @@
#include "pathnames.h"
/* "@(#)compat.c 8.2 (Berkeley) 3/19/94" */
-MAKE_RCSID("$NetBSD: compat.c,v 1.180 2020/11/08 08:26:22 rillig Exp $");
+MAKE_RCSID("$NetBSD: compat.c,v 1.181 2020/11/08 08:33:07 rillig Exp $");
static GNode *curTarg = NULL;
static pid_t compatChild;
@@ -497,10 +497,10 @@ Compat_Make(GNode *gn, GNode *pgn)
* All the children were made ok. Now youngestChild->mtime contains the
* modification time of the newest child, we need to find out if we
* exist and when we were modified last. The criteria for datedness
* are defined by the Make_OODate function.
*/
DEBUG1(MAKE, "Examining %s...", gn->name);
- if (!Make_OODate(gn)) {
+ if (!GNode_IsOODate(gn)) {
gn->made = UPTODATE;
DEBUG0(MAKE, "up-to-date.\n");
goto cohorts;
@@ -497,10 +497,10 @@ Compat_Make(GNode *gn, GNode *pgn)
* modification time of the newest child, we need to find out if we
* exist and when we were modified last. The criteria for datedness
- * are defined by the Make_OODate function.
+ * are defined by GNode_IsOODate.
*/
DEBUG1(MAKE, "Examining %s...", gn->name);